diff --git a/packages/component-faraday-ui/src/ActionLink.js b/packages/component-faraday-ui/src/ActionLink.js
index 9f27cec30d1ba8e1584fed2f753653c952e23f77..05ad25cd28ff0ec15c333469b13f6ec6c16e9402 100644
--- a/packages/component-faraday-ui/src/ActionLink.js
+++ b/packages/component-faraday-ui/src/ActionLink.js
@@ -78,7 +78,7 @@ const Root = styled.div`
   ${marginHelper};
   ${paddingHelper};
 
-  height: max-content;
+  height: ${props => (props.height ? `${props.height}px` : 'max-content')};
   width: max-content;
 
   & span {
diff --git a/packages/component-faraday-ui/src/ManuscriptCard.js b/packages/component-faraday-ui/src/ManuscriptCard.js
index ae360b12e7ae2b3220528f7e771b5cac322bd377..17e9e176354403406b6066cf5b09f589a9a93cfa 100644
--- a/packages/component-faraday-ui/src/ManuscriptCard.js
+++ b/packages/component-faraday-ui/src/ManuscriptCard.js
@@ -24,6 +24,7 @@ import { OpenModal } from './modals'
 const ManuscriptCard = ({
   onDelete,
   canDelete,
+  isFetching,
   onCardClick,
   canViewReports,
   fragment = {},
@@ -87,16 +88,17 @@ const ManuscriptCard = ({
             <Item justify="flex-end" onClick={e => e.stopPropagation()}>
               <OpenModal
                 confirmText="Delete"
+                isFetching={isFetching}
                 modalKey={`delete-${collId}`}
                 onConfirm={onDelete}
                 title="Are you sure you want to delete this submission?"
               >
-                {onClickEvent => (
+                {showModal => (
                   <ActionLink
+                    height={16}
                     icon="trash"
-                    onClick={onClickEvent}
+                    onClick={showModal}
                     size="small"
-                    style={{ height: 16 }}
                   >
                     Delete
                   </ActionLink>
diff --git a/packages/component-helper-service/src/services/Team.js b/packages/component-helper-service/src/services/Team.js
index dd3050ebddd07abe3bf447ecea75676ca0ebd3e2..631bd09291af51bdacb90ec2978b374a1c672511 100644
--- a/packages/component-helper-service/src/services/Team.js
+++ b/packages/component-helper-service/src/services/Team.js
@@ -130,6 +130,15 @@ class Team {
     )
   }
 
+  async getTeams(objectType) {
+    const { TeamModel, fragmentId, collectionId } = this
+    const objectId = objectType === 'collection' ? collectionId : fragmentId
+    const teams = await TeamModel.all()
+    return teams.filter(
+      team => team.object.type === objectType && team.object.id === objectId,
+    )
+  }
+
   async deleteHandlingEditor({ collection, role, user }) {
     const team = await this.getTeam({
       role,
diff --git a/packages/component-manuscript-manager/src/routes/collections/delete.js b/packages/component-manuscript-manager/src/routes/collections/delete.js
new file mode 100644
index 0000000000000000000000000000000000000000..05b9e042f9c08c24f9367aea7f6db546e08e8b08
--- /dev/null
+++ b/packages/component-manuscript-manager/src/routes/collections/delete.js
@@ -0,0 +1,78 @@
+const { get, remove, concat } = require('lodash')
+const config = require('config')
+
+const {
+  Team,
+  services,
+  authsome: authsomeHelper,
+} = require('pubsweet-component-helper-service')
+
+const {
+  deleteFilesS3,
+} = require('pubsweet-component-mts-package/src/PackageManager')
+
+const s3Config = get(config, 'pubsweet-component-aws-s3', {})
+
+module.exports = models => async (req, res) => {
+  const { collectionId } = req.params
+  let collection, fragment
+  try {
+    collection = await models.Collection.find(collectionId)
+
+    const fragmentId = collection.fragments[0]
+    fragment = await models.Fragment.find(fragmentId)
+
+    const authsome = authsomeHelper.getAuthsome(models)
+
+    const canDelete = await authsome.can(req.user, 'DELETE', collection)
+    if (!canDelete)
+      return res.status(403).json({
+        error: 'Unauthorized.',
+      })
+
+    const teamHelper = new Team({
+      TeamModel: models.Team,
+      fragmentId,
+      collectionId,
+    })
+    const teams = await teamHelper.getTeams('fragment')
+
+    await Promise.all(
+      teams.map(async team => {
+        await Promise.all(
+          team.members.map(async member => {
+            const user = await models.User.find(member)
+
+            remove(user.teams, teamId => teamId === team.id)
+
+            return user.save()
+          }),
+        )
+
+        return team.delete()
+      }),
+    )
+
+    const fileKeys = concat(
+      fragment.files.manuscripts,
+      fragment.files.coverLetter,
+      fragment.files.supplementary,
+      fragmentId,
+    ).map(file => file.id)
+
+    if (fileKeys.length > 1) {
+      await deleteFilesS3({ fileKeys, s3Config })
+    }
+
+    await fragment.delete()
+
+    await collection.delete()
+
+    return res.status(204).send()
+  } catch (e) {
+    const notFoundError = await services.handleNotFoundError(e, 'Item')
+    return res.status(notFoundError.status).json({
+      error: notFoundError.message,
+    })
+  }
+}
diff --git a/packages/component-mts-package/src/PackageManager.js b/packages/component-mts-package/src/PackageManager.js
index b98dbf10308c84b927b10d3f670b285a1b6ca8b7..cb9b8ea4c9fd644ef72c146706dde13348283cc4 100644
--- a/packages/component-mts-package/src/PackageManager.js
+++ b/packages/component-mts-package/src/PackageManager.js
@@ -115,6 +115,26 @@ const uploadFiles = async ({ filename, s3Config, config }) => {
     .catch(fileError(filename))
 }
 
+const deleteFilesS3 = async ({ fileKeys, s3Config }) => {
+  AWS.config.update({
+    secretAccessKey: s3Config.secretAccessKey,
+    accessKeyId: s3Config.accessKeyId,
+    region: s3Config.region,
+  })
+  const s3 = new AWS.S3()
+
+  const params = {
+    Bucket: s3Config.bucket,
+    Delete: {
+      Objects: fileKeys.map(file => ({ Key: file })),
+    },
+  }
+
+  const deleteObjectsS3 = promisify(s3.deleteObjects.bind(s3))
+
+  return deleteObjectsS3(params)
+}
+
 const deleteFile = filename => {
   fs.access(filename, fs.constants.F_OK, err => {
     if (!err) {
@@ -138,4 +158,5 @@ const uploadFTP = ({ filename, config }) => {
 module.exports = {
   createFilesPackage,
   uploadFiles,
+  deleteFilesS3,
 }
diff --git a/packages/components-faraday/src/components/Dashboard/Dashboard.js b/packages/components-faraday/src/components/Dashboard/Dashboard.js
index 0c106443fd6d2da18ebbdce662c5d738bc6b8dd8..a03dce5045de7b34967ca35b9bc7c8d7ec24180c 100644
--- a/packages/components-faraday/src/components/Dashboard/Dashboard.js
+++ b/packages/components-faraday/src/components/Dashboard/Dashboard.js
@@ -4,12 +4,13 @@ import { compose, withProps } from 'recompose'
 import { DashboardItems, DashboardFilters } from './'
 
 const Dashboard = ({
-  deleteProject,
+  journal,
+  isFetching,
   dashboardItems,
+  deleteCollection,
   getFilterOptions,
   changeFilterValue,
   getDefaultFilterValue,
-  journal,
 }) => (
   <Fragment>
     <DashboardFilters
@@ -17,7 +18,11 @@ const Dashboard = ({
       getDefaultFilterValue={getDefaultFilterValue}
       getFilterOptions={getFilterOptions}
     />
-    <DashboardItems deleteProject={deleteProject} list={dashboardItems} />
+    <DashboardItems
+      deleteCollection={deleteCollection}
+      isFetching={isFetching}
+      list={dashboardItems}
+    />
   </Fragment>
 )
 
diff --git a/packages/components-faraday/src/components/Dashboard/DashboardItems.js b/packages/components-faraday/src/components/Dashboard/DashboardItems.js
index f5a5e24df3fff52a255f0a70b427cec11726a782..72d16891c5a40b967a4f7e5491dd9180c05e186d 100644
--- a/packages/components-faraday/src/components/Dashboard/DashboardItems.js
+++ b/packages/components-faraday/src/components/Dashboard/DashboardItems.js
@@ -5,9 +5,9 @@ import { connect } from 'react-redux'
 import styled from 'styled-components'
 import { th } from '@pubsweet/ui-toolkit'
 import { withRouter } from 'react-router-dom'
-import { compose, setDisplayName, withHandlers, withProps } from 'recompose'
 import { ManuscriptCard, Row } from 'pubsweet-component-faraday-ui'
 import { canViewReports } from 'pubsweet-component-faraday-selectors'
+import { compose, setDisplayName, withHandlers, withProps } from 'recompose'
 
 const DashboardItem = compose(
   connect((state, { collection }) => ({
@@ -18,7 +18,13 @@ const DashboardItem = compose(
   })),
 )(ManuscriptCard)
 
-const DashboardItems = ({ list, onClick, deleteProject, canViewReports }) => (
+const DashboardItems = ({
+  list,
+  onClick,
+  isFetching,
+  canViewReports,
+  deleteCollection,
+}) => (
   <Root data-test-id="dashboard-list-items">
     {!list.length ? (
       <Row justify="center" mt={4}>
@@ -29,9 +35,10 @@ const DashboardItems = ({ list, onClick, deleteProject, canViewReports }) => (
         <HideLoading key={collection.id}>
           <DashboardItem
             collection={collection}
+            isFetching={isFetching}
             key={collection.id}
             onClick={onClick}
-            onDelete={() => deleteProject(collection)}
+            onDelete={deleteCollection(collection)}
           />
         </HideLoading>
       ))
diff --git a/packages/components-faraday/src/components/Dashboard/DashboardPage.js b/packages/components-faraday/src/components/Dashboard/DashboardPage.js
index eda5819b44ca04a7b91afc876a6cec42bba2569c..2aadccce522ce995b4387b64b0f1b891433befe9 100644
--- a/packages/components-faraday/src/components/Dashboard/DashboardPage.js
+++ b/packages/components-faraday/src/components/Dashboard/DashboardPage.js
@@ -4,8 +4,9 @@ import { actions } from 'pubsweet-client'
 import { withJournal } from 'xpub-journal'
 import { ConnectPage } from 'xpub-connect'
 import { withRouter } from 'react-router-dom'
-import { compose, withContext } from 'recompose'
 import { selectCurrentUser } from 'xpub-selectors'
+import { compose, withHandlers, withContext } from 'recompose'
+import { handleError, withFetching } from 'pubsweet-component-faraday-ui'
 
 import {
   getUserPermissions,
@@ -32,13 +33,13 @@ export default compose(
         userPermissions,
       }
     },
-    dispatch => ({
-      deleteProject: collection =>
-        dispatch(actions.deleteCollection(collection)),
-    }),
+    {
+      deleteCollection: actions.deleteCollection,
+    },
   ),
   withRouter,
   withJournal,
+  withFetching,
   withFiltersHOC({
     priority: priorityFilter,
     order: orderFilter,
@@ -50,4 +51,23 @@ export default compose(
     },
     ({ journal, currentUser }) => ({ journal, currentUser }),
   ),
+  withHandlers({
+    deleteCollection: ({ setFetching, deleteCollection }) => collection => ({
+      hideModal,
+      setModalError,
+    }) => {
+      setFetching(true)
+      deleteCollection(collection)
+        .then(() => {
+          setFetching(false)
+          hideModal()
+        })
+        // again, the error is not being thrown from deleteCollection action and
+        // the catch is never run
+        .catch(err => {
+          setFetching(false)
+          handleError(setModalError)(err)
+        })
+    },
+  }),
 )(Dashboard)
diff --git a/packages/component-manuscript-manager/src/Collections.js b/packages/component-manuscript-manager/src/Collections.js
index 8ce7c79779abb552a2728ad835b3e078d21ccaa8..81f8c4d7f6977ae496a3d021ac6dbc0a7be37dca 100644
--- a/packages/component-manuscript-manager/src/Collections.js
+++ b/packages/component-manuscript-manager/src/Collections.js
@@ -7,8 +7,8 @@ const Collections = app => {
     session: false,
   })
   /**
    * @api {get} /api/fragments Get latest fragments
    * @apiGroup Fragments
    * @apiSuccessExample {json} Success
    *    HTTP/1.1 200 OK
    *    [
@@ -28,7 +28,7 @@ const Collections = app => {
    *        }
    *      }
    *    ]
    * @apiErrorExample {json} Get fragments errors
    *    HTTP/1.1 403 Forbidden
    */
   app.get(
@@ -36,6 +36,20 @@ const Collections = app => {
     authBearer,
     require(`${routePath}/get`)(app.locals.models),
   )
+
+  /**
+   * @api {delete} /api/collections/:collectionId Delete collection with specified id
+   * @apiGroup Collections
+   * @apiSuccessExample {json} Success
+   *    HTTP/1.1 204 Accepted
+   * @apiErrorExample {json} Get collections errors
+   *    HTTP/1.1 403 Forbidden
+   */
+  app.delete(
+    '/api/collections/:collectionId',
+    authBearer,
+    require(`${routePath}/delete`)(app.locals.models),
+  )
 }
 
 module.exports = Collections
@@ -7,8 +7,8 @@ const Collections = app => {
   })
   /**
-   * @api {get} /api/fragments Get latest fragments
-   * @apiGroup Fragments
+   * @api {get} /api/collections Get latest collections
+   * @apiGroup Collections
    * @apiSuccessExample {json} Success
    *    HTTP/1.1 200 OK
@@ -28,7 +28,7 @@ const Collections = app => {
    *      }
    *    ]
-   * @apiErrorExample {json} Get fragments errors
+   * @apiErrorExample {json} Get collections errors
    *    HTTP/1.1 403 Forbidden
    */